==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let CancellingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancellingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.j(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.aa("CancellingMultiScaleImageEventArgs", () => new CancellingMultiScaleImageEventArgsDescription());
            a.z("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
export let CancellingMultiScaleImageEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class CancellingMultiScaleImageEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
                CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
            }
            if (a.k(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("Uri", "String");
        }
        static d(a) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
            a.ac("CancellingMultiScaleImageEventArgs", () => new CancellingMultiScaleImageEventArgsDescription());
            a.ab("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
})();
